# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.19.8](https://github.com/mamba-org/rattler/compare/rattler_virtual_packages-v0.19.7...rattler_virtual_packages-v0.19.8) - 2024-04-25

### Other
- updated the following local packages: rattler_conda_types

## [0.19.7](https://github.com/mamba-org/rattler/compare/rattler_virtual_packages-v0.19.6...rattler_virtual_packages-v0.19.7) - 2024-04-19

### Other
- update dependencies incl. reqwest ([#606](https://github.com/mamba-org/rattler/pull/606))

## [0.19.6](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v0.19.5...rattler_virtual_packages-v0.19.6) - 2024-04-05

### Other
- updated the following local packages: rattler_conda_types

## [0.19.5](https://github.com/mamba-org/rattler/compare/rattler_virtual_packages-v0.19.4...rattler_virtual_packages-v0.19.5) - 2024-03-30

### Added
- proper archspec detection using archspec-rs ([#584](https://github.com/mamba-org/rattler/pull/584))

## [0.19.4](https://github.com/mamba-org/rattler/compare/rattler_virtual_packages-v0.19.3...rattler_virtual_packages-v0.19.4) - 2024-03-21

### Other
- updated the following local packages: rattler_conda_types

## [0.19.3](https://github.com/mamba-org/rattler/compare/rattler_virtual_packages-v0.19.2...rattler_virtual_packages-v0.19.3) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/mamba-org/rattler/pull/563))

## [0.19.2](https://github.com/mamba-org/rattler/compare/rattler_virtual_packages-v0.19.1...rattler_virtual_packages-v0.19.2) - 2024-03-08

### Other
- updated the following local packages: rattler_conda_types

## [0.19.1](https://github.com/mamba-org/rattler/compare/rattler_virtual_packages-v0.19.0...rattler_virtual_packages-v0.19.1) - 2024-03-06

### Fixed
- dont use workspace dependencies for local crates ([#546](https://github.com/mamba-org/rattler/pull/546))

### Other
- every crate should have its own version ([#557](https://github.com/mamba-org/rattler/pull/557))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_virtual_packages-v0.18.0...rattler_virtual_packages-v0.19.0) - 2024-02-26
